- EsetDiff
An ExpressionSet object storing the log2 difference
between post-treatment and pre-treatment.
- fmla
A formula without outcome variable.
- probeID.var
character. Indicates the probe id.
- gene.var
character. Indicates the gene symbol.
- chr.var
character. Indicates the chromosome.
- scaleFlag
logical. Indicating if rows (probes) need to be scaled (but not centered).
- Maxiter
integer.
The max allowed number of iterations for EM algorithm. Default value is maxRT = 100.
- maxIT
integer. The max allowed number of iterations in R built-in function optim. Default value is maxIT = 100.
maxIT.
- b
numeric.
A vector of concentration parameters used in Dirichlet distribution. Default value is b = c(2,2,2).
- converge_threshold
numeric.
One of the two termination criteria of iteration.
The smaller this value is set, the harder the optimization procedure in eLNNpaired will be considered to be converged. Default value is converge_threshold = 1e-6.
- optimMethod
character. Indicates the method for optimization. optim.
- bound.alpha
numeric. A vector of 2 positive numbers to specify lower and upper bound of estimate of \(\alpha_c\), c="OE", "UE", or "NE".
- bound.beta
numeric. A vector of 2 positive numbers to specify lower and upper bound of estimate of \(\beta_c\), c="OE", "UE", or "NE".
- bound.k
numeric. A vector of 2 positive numbers to specify lower and upper bound of estimate of \(k_c\), c="OE", "UE", or "NE".
- bound.eta
numeric. A vector of p+1 positive numbers to specify lower and upper bound of estimate of \(\eta_c\), c="OE", "UE", or "NE",
where p is the number of covariates.
- mc.cores
integer. A positive integer specifying number of computer cores to be used by parallel computing.
- temp0
numeric. Initial temperature in simulated-annealing modified EM.
- r_cool
numeric. Cooling rate in simulated-annealing modified EM, which is inside interval \((0, 1)\).
- verbose
logic.
An indicator variable telling if print out intermediate results: FALSE for not printing out, TRUE for printing out. Default value is verbose = False.